#========================================================================================
# package      DE_EPAGES::Order::Hooks::OrderDocument
# state        private
# description  Hook module for order.
#========================================================================================
package DE_EPAGES::Order::Hooks::OrderDocument;

use strict;
use DE_EPAGES::Order::API::Shop qw (ProcessOrderDocumentTextAttributes);
use DE_EPAGES::Core::API::File qw (CopyFile fsplit);

#========================================================================================
# function     OnFinishShopWizard
#----------------------------------------------------------------------------------------
# syntax       OnFinishShopWizard( $hValues );
#----------------------------------------------------------------------------------------
# description  on finish shop wizard set OrderDocumentText2
#               (Hook UI_FinishShopWizard)
#----------------------------------------------------------------------------------------
# input        $hValues | form values which are supplied by Form ShopWizard of class Shop.
#               <ul>
#                   <li>Shop - the current Shop - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnFinishShopWizard {
    my ($hValues) = @_;
    my $Shop = $hValues->{'Shop'};

    if ($Shop->get('IsUnityRegistered')){
        ProcessOrderDocumentTextAttributes($Shop, 'UnityMBO-OrderDocumentText2', 1);

        # copy the shop attribute Logo to OrderDocumentsLogo and also copy file Logo.* to OrderDocumentsLogo.*
        my $ShopLogo = $Shop->get('Logo');
        if($ShopLogo) {
            my $SourceFilePathAndName = $Shop->get('PublicPath') . '/'. $ShopLogo;

            my (undef, undef, $Extension) = fsplit($SourceFilePathAndName);
            my $TargetFileName = 'OrderDocumentsLogo' . $Extension;
            my $TargetFilePathAndName = $Shop->get('PublicPath') . '/'. $TargetFileName ;
            CopyFile($SourceFilePathAndName, $TargetFilePathAndName, {create_directory => 1});
            $Shop->set({'OrderDocumentsLogo' => $TargetFileName });
        }            

    } else {
        ProcessOrderDocumentTextAttributes($Shop, 'MBO-OrderDocumentText2');
    }

    return;
}

1;
