#========================================================================================
# package      DE_EPAGES::ServiRed::t::unit::LineItemPaymentServiRed
# state        public
#----------------------------------------------------------------------------------------
# description  Test class use to test the DE_EPAGES::ServiRed::API::Object::LineItemPaymentServiRed
#========================================================================================
package DE_EPAGES::ServiRed::t::unit::LineItemPaymentServiRed;
use base DE_EPAGES::Core::API::Test;

use strict;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

sub test {
    my $self = shift;

    $self->test_updateOnExecute_on_order_without_non_digits_order_alias();
    $self->test_updateOnExecute_on_order_with_non_digits_order_alias();
    $self->test_updateOnExecute_on_basket();

    done_testing();
}

sub test_updateOnExecute_on_order_without_non_digits_order_alias {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    $SUT->updateOnExecute( { 'Order' => $self->_createOrder('20201003') } );

    like(
        $SUT->get('TransID'),
        qr/^20201003\d+/,
        "$SubTestName - transID LineItemPayment field set with only digits from Order alias."
    );
}

sub test_updateOnExecute_on_order_with_non_digits_order_alias {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    $SUT->updateOnExecute( { 'Order' => $self->_createOrder('2020/1003') } );

    like(
        $SUT->get('TransID'),
        qr/^20201003\d+/,
        "$SubTestName - transID LineItemPayment field set with only digits (while Order alias have non-digits)."
    );
}

sub test_updateOnExecute_on_basket {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    $SUT->updateOnExecute( {} );

    like(
        $SUT->get('TransID'),
        qr/^31659\d+/,
        "$SubTestName - transID LineItemPayment field set with only digits from LineItemContainer object id."
    );
}

#--------------------------------------------------
# Helpers
#--------------------------------------------------

sub _createSUT {
    my $self = shift;

    my $hAttributes = {
        'PaymentMethod' => $self->_createPaymentMethod(),
        'TransID' => undef
    };
    my $MockifySut = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::ServiRed::API::Object::LineItemPaymentServiRed', $hAttributes);

    $MockifySut->addMockWithReturnValue('container', $self->_createLineItemContainer());

    return $MockifySut->getMockObject();
}

sub _createOrder {
    my $self = shift;
    my ($OrderAlias) = @_;

    my $hAttributes = {};
    my $MockifyOrder = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Order::API::Object::CustomerOrder',
        $hAttributes
    );
    $MockifyOrder->addMockWithReturnValue('alias', $OrderAlias);

    return $MockifyOrder->getMockObject();
}

sub _createLineItemContainer {
    my $self = shift;

    my $hAttributes = {
        'CurrencyID' => 'EUR',
        'GrandTotal' => undef
    };
    my $MockifyLineItemContainer = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Order::API::Object::LineItemContainer',
        $hAttributes
    );
    $MockifyLineItemContainer->addMockWithReturnValue('id', '31659');

    return $MockifyLineItemContainer->getMockObject();
}

sub _createPaymentMethod {
    my $self = shift;

    my $hAttributes = {
        'IsInTestMode' => 1,
        'TransactionType' => 0
    };
    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::ServiRed::API::Object::PaymentMethodServiRed',
        $hAttributes
    );

    return $MockifyPaymentMethod->getMockObject();
}

#==================================================
# Main
#==================================================

__PACKAGE__->runScript();

1;