#========================================================================================
# package    DE_EPAGES::Spreedly::t::unit::PaymentMethodSpreedlyPayULatam
# base       DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for 
#========================================================================================
package DE_EPAGES::Spreedly::t::unit::PaymentMethodSpreedlyPayULatam;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

sub test {
        my $self = shift;

        $self->_buildMocks();

        $self->test_canAddToBasket();
        $self->test_default();
        $self->test_insert();
        $self->test_usableAtStorefront();

        done_testing();
}
#----------------------------------------------------------------------------------------
sub test_canAddToBasket {
        my $self = shift;
        my $SubTestName = (caller(0))[3];

        my $hVars;
        my $SUT = $self->memory()->get( 'SUT' );

        $hVars->{skipUsableAtStorefrontCheck} = 0;

        my $response = $SUT->canAddToBasket($hVars);

        is($response , 1 , "$SubTestName - Payment Method Spreedly PayULatam can be added to a Basket" );

}
#----------------------------------------------------------------------------------------
sub test_default {
        my $self = shift;
        my $SubTestName = (caller(0))[3];

        my $hInfo;
        my $Parent;
        my $SUT = $self->memory()->get( 'SUT' );

        $hInfo->{'PaymentTypeMethod'} = 'CreditCard';

        my $response = $SUT->default($Parent,$hInfo);

        is($response->{test}, 1 , "$SubTestName - Default settings are applied" );

}
#----------------------------------------------------------------------------------------
sub test_insert {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hInfo;;
    my $SUT = $self->memory()->get( 'SUT' );

    $hInfo->{skipUsableAtStorefrontCheck} = 0;

    my $Response = $SUT->insert($hInfo);

    is($Response->get('Alias') , 'CreditCard' , "$SubTestName - Check name of payment method created" );
    is($Response->get('Name') , 'DemoShop' , "$SubTestName - Check site of payment method created" );

}
#----------------------------------------------------------------------------------------
sub test_usableAtStorefront {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hVars = { 'test' => 1 };
    my $SUT = $self->memory()->get( 'SUT' );

    my $response = $SUT->usableAtStorefront($hVars);

    is($response , 1 , "$SubTestName - unit Test for method usableAtStorefront" );

}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _buildMocks {
        my $self = shift;

        my $SUT = $self->_createSUT();
        $self->memory()->add( 'SUT', $SUT );
}
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;

    # PayU test credentials
    my $aParameterList = [
        'ApiLogin'       => 'pRRXKOl8ikMmt9u',
        'ApiKey'         => '4Vj8eK4rloUd272L48hsrarnUA',
        'MerchantID'     => '508029',
        'AccountID'      => '512324',
        'PaymentCountry' => 'MX'
    ];

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new
          (
               'DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedlyPayULatam',
               $aParameterList
          );


    my $aParameterTypes = ['hashref'];
    my $aParameterTypesSuperDefault = ['undef','hashref'];
    my $SuperDefaultReturn = {
        'test'  => '1'
    };
    my $DefaultPaymentTypeMethod = $self->_createMockedPaymentTypeMethod();
    my $PaymentMethodSpreedly = $self->_getPaymentMethodSpreedly();

    $Mockify->addMockWithReturnValueAndParameterCheck('_callSuperCanAddToBasket',1,$aParameterTypes);
    $Mockify->addMockWithReturnValue('_getDefaultPaymentTypeMethod',$DefaultPaymentTypeMethod);
    $Mockify->addMockWithReturnValueAndParameterCheck('_callSuperDefault',$SuperDefaultReturn,$aParameterTypesSuperDefault);
    $Mockify->addMockWithReturnValueAndParameterCheck('_callSuperInsert',$PaymentMethodSpreedly,$aParameterTypes);
    $Mockify->addMockWithReturnValueAndParameterCheck('_callSuperUsableAtStorefront',1,$aParameterTypes);

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createMockedPaymentTypeMethod {
    my $self = shift;

    my $hAttributes = {
        'Alias'             => 'Default Credit Card Name'
    };

    my $MockifyPaymentTypeMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::ExternalPayment::API::Object::PaymentTypeMethod', $hAttributes
    );

    return $MockifyPaymentTypeMethod->getMockObject();
}

sub _getPaymentMethodSpreedly {
    my $self = shift;

    my $hAttributes = {
        'Alias'             => 'CreditCard',
        'Name'              => 'DemoShop'
    };

    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedly', $hAttributes
    );

    my $PaymentMethods = $self->_getPaymentMethodsObject();
    $MockifyPaymentMethod->addMockWithReturnValue('parent', $PaymentMethods);


    return $MockifyPaymentMethod->getMockObject;
}

sub _getPaymentMethodsObject {
    my $self = shift;

    my $Shop = $self->mockFactory()->buildShop
        ({
            'Alias' => 'TestShop',
            'LanguageID' => 1,

        })->getMockObject();

    my $hAttributes = {
        'Site'             => $Shop
    };

    my $MockifyPaymentMethods = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Object::API::Object::Object', $hAttributes
    );


    return $MockifyPaymentMethods->getMockObject();
}

__PACKAGE__->runScript();